@@ -9,8 +9,7 @@ use base qw{ PPIx::QuoteLike::Token };
 
 use PPIx::QuoteLike::Constant qw{ @CARP_NOT };
 
-our $VERSION = '0.013';
-
+our $VERSION = '0.016';
 
 1;
 
@@ -32,7 +31,6 @@ L<PPIx::QuoteLike::Token|PPIx::QuoteLike::Token>.
 
 C<PPIx::QuoteLike::Token::String> has no descendants.
 
-
 =head1 DESCRIPTION
 
 This Perl class represents a literal, uninterpolated string.
@@ -42,7 +40,6 @@ This Perl class represents a literal, uninterpolated string.
 This class supports no public methods in addition to those of its
 superclass.
 
-
 =head1 SEE ALSO
 
 L<PPIx::QuoteLike::Token|PPIx::QuoteLike::Token>.
@@ -50,7 +47,9 @@ L<PPIx::QuoteLike::Token|PPIx::QuoteLike::Token>.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org>, or in electronic mail to the author.
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=PPIx-QuoteLike>,
+L<https://github.com/trwyant/perl-PPIx-QuoteLike/issues>, or in
+electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -58,7 +57,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2016-2020 by Thomas R. Wyant, III
+Copyright (C) 2016-2021 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
